<?php
/**
 * Created by PhpStorm.
 * User: jderosa
 * Date: 21/03/19
 * Time: 14.49
 */

namespace FiloBlu\RuleDayFromBirthday\Model\Rule\Condition\Customer;

use Magento\Customer\Api\CustomerRepositoryInterface;
use Magento\Framework\Stdlib\DateTime\DateTimeFactory;
use Magento\Sales\Model\ResourceModel\Order\CollectionFactory;

class FirstOrder extends \Magento\Rule\Model\Condition\AbstractCondition
{

    /**
     * @var CustomerRepositoryInterface
     */
    protected $customerRepository;

    /**
     * @var \Magento\Sales\Model\ResourceModel\Order\CollectionFactory
     */
    protected $orderFactory;

    /**
     * FirstOrder constructor.
     * @param \Magento\Rule\Model\Condition\Context $context
     * @param CustomerRepositoryInterface $customerRepository
     * @param CollectionFactory $orderFactory
     * @param array $data
     */
    public function __construct(
        \Magento\Rule\Model\Condition\Context $context,
        CustomerRepositoryInterface $customerRepository,
        CollectionFactory $orderFactory,
        array $data = []
    ) {
        parent::__construct($context, $data);
        $this->customerRepository = $customerRepository;
        $this->orderFactory = $orderFactory;

    }
    /**
     * Load attribute options
     *
     * @return $this
     */
    public function loadAttributeOptions()
    {
        $attributes = [
            'customer_first_order' => __("Days from customer's first order")
        ];
        $this->setAttributeOption($attributes);
        return $this;
    }
    /**
     * Get input type
     * Possible values are: string, numeric, date, select, multiselect, grid, boolean
     *
     * @return string
     */
    public function getInputType()
    {
        return 'string';
    }
    /**
     * Get value element type
     *
     * We have the value element types as select, text
     * @return string
     */
    public function getValueElementType()
    {
        return 'text';
    }

     /**
     * @param $order_created_at
     * @return int
     */
    protected function getDaysFromOrder($order_created_at)
    {
        $interval = strtotime("now") - strtotime($order_created_at);
        $num_of_days = (int) ($interval/86400);
        return $num_of_days;
    }


    /**
     * @param \Magento\Framework\Model\AbstractModel $model
     * @return bool
     */
    public function validate(\Magento\Framework\Model\AbstractModel $model)
    {

        // Get the customer id of the current customer
        $customerId = (int)$model->getCustomerId();

        $order = $this->orderFactory->create($customerId);

        $all_orders = $order->getItems();
        $num_orders = count($all_orders);
        $order_created_at = [];


        if($num_orders >= 1)
        {

            foreach ($all_orders as $items)
            {

              $order_created_at [] = $items->getCreatedAt();

            }
            //retrieve created_at from first order only
            $val = $this->getDaysFromOrder($order_created_at[0]);

            $model->setData('customer_first_order', $val);

            return parent::validate($model);
        }
        else
        {
            return false;
        }



    }
}